@@ -871,6 +871,7 @@ END
    ($stdout,$stderr)=$handle->cmd(
       "${sudo}echo -e \"$config_email\" >> /var/www/gnusocial/config.php");
    if ($twitter_api_key && $twitter_api_key!~/gnusocial_twitter_api/) {
+      $site_name=~s/[']/\\'/g;
       my $config_twitter=<<END;
 addPlugin(
    'TwitterBridge',
@@ -1717,12 +1718,6 @@ our $gnusocial_enter_values=sub {
    my $permanent_ip="]T[{permanent_ip}";
    if ($main::aws->{permanent_ip}) {
       $permanent_ip=$main::aws->{permanent_ip};
-   #} elsif ($permanent_ip=~/Allocate/) {
-   #   my $c="aws ec2 allocate-address --domain vpc";
-   #   my ($hash,$output,$error)=
-   #         &Net::FullAuto::Cloud::fa_amazon::run_aws_cmd($c);
-   #   $hash||={};
-   #   $permanent_ip=$main::aws->{permanent_ip}=$hash->{PublicIp};
    } elsif ($permanent_ip=~s/^.*Elastic.* (\d+\.\d+\.\d+\.\d+).*$/$1/s) {
    } else {
       STDOUT->autoflush(1);
